"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Neogma = void 0;
const neo4j_driver = __importStar(require("neo4j-driver"));
const QueryRunner_1 = require("./Queries/QueryRunner");
const Sessions_1 = require("./Sessions/Sessions");
const NeogmaConnectivityError_1 = require("./Errors/NeogmaConnectivityError");
const neo4j = neo4j_driver;
class Neogma {
    /**
     *
     * @param {ConnectParamsI} params - the connection params
     * @param {ConnectOptionsI} options - additional options for the QueryRunner
     */
    constructor(params, options) {
        /** a map between each Model's modelName and the Model itself */
        this.modelsByName = {};
        this.verifyConnectivity = async () => {
            try {
                await this.driver.verifyConnectivity();
            }
            catch (err) {
                throw new NeogmaConnectivityError_1.NeogmaConnectivityError(err);
            }
        };
        this.getSession = (runInSession, callback, 
        /**
         * Override the configuration of the session.
         * By default, the "database" param used in the constructor is always passed.
         */
        sessionConfig) => {
            return (0, Sessions_1.getSession)(runInSession, callback, this.driver, Object.assign({ database: this.database }, sessionConfig));
        };
        this.getTransaction = (runInTransaction, callback, 
        /**
         * Override the configuration of the session.
         * By default, the "database" param used in the constructor is always passed.
         */
        sessionConfig) => {
            return (0, Sessions_1.getTransaction)(runInTransaction, callback, this.driver, Object.assign({ database: this.database }, sessionConfig));
        };
        this.getRunnable = (runInExisting, callback, 
        /**
         * Override the configuration of the session.
         * By default, the "database" param used in the constructor is always passed.
         */
        sessionConfig) => {
            return (0, Sessions_1.getRunnable)(runInExisting, callback, this.driver, Object.assign({ database: this.database }, sessionConfig));
        };
        const { url, username, password } = params;
        try {
            this.driver = neo4j.driver(url, neo4j.auth.basic(username, password), options);
            this.database = params.database;
        }
        catch (err) {
            throw new NeogmaConnectivityError_1.NeogmaConnectivityError(err);
        }
        this.queryRunner = new QueryRunner_1.QueryRunner({
            driver: this.driver,
            logger: options === null || options === void 0 ? void 0 : options.logger,
            sessionParams: {
                database: this.database,
            },
        });
    }
}
exports.Neogma = Neogma;
//# sourceMappingURL=Neogma.js.map